@@ -128,9 +128,10 @@ to_build_duration_df <- function(times){
 # we need to round to the nearest second
 # for times longer than a minute.
 to_build_duration <- function(x){
+  assert_pkgs("lubridate")
   round_these <- x >= 60
   x[round_these] <- round(x[round_these], digits = 0)
-  dseconds(x)
+  lubridate::dseconds(x)
 }
 
 time_columns <- c("elapsed", "user", "system")
