@@ -4,7 +4,7 @@
 #' is used to compute the metadata of targets.
 #' @details Target metadata is computed
 #' with `drake_meta()`, and then
-#' `drake:::finish_meta()` completes the metadata
+#' `drake:::store_outputs()` completes the metadata
 #' after the target is built.
 #' In other words, the output of `drake_meta()` corresponds
 #' to the state of the target immediately before [make()]
@@ -15,8 +15,8 @@
 #' @export
 #' @return A list of metadata on a target. Does not include
 #'   the file modification time if the target is a file.
-#'   That piece is provided later in [make()] by
-#'   `drake:::finish_meta`.
+#'   That piece is computed later in [make()] by
+#'   `drake:::store_outputs()`.
 #' @param target Character scalar, name of the target
 #'   to get metadata.
 #' @param config Master internal configuration list produced
@@ -47,12 +47,31 @@
 #' }
 drake_meta <- function(target, config = drake::read_drake_config()) {
   meta <- list(
+    name = target,
     target = target,
     imported = !(target %in% config$plan$target),
     foreign = !exists(x = target, envir = config$envir, inherits = FALSE),
     missing = !target_exists(target = target, config = config),
-    seed = seed_from_object(list(seed = config$seed, target = target))
+    seed = seed_from_object(list(seed = config$seed, target = target)),
+    output_files = unlist(
+      igraph::vertex_attr(
+        graph = config$graph,
+        name = "output_files",
+        index = target
+      )
+    ),
+    input_files = unlist(
+      igraph::vertex_attr(
+        graph = config$graph,
+        name = "input_files",
+        index = target
+      )
+    )
   )
+  # For imported files.
+  if (is_file(target)) {
+    meta$mtime <- file.mtime(drake::drake_unquote(target))
+  }
   trigger <- get_trigger(target = target, config = config)
   # Need to make sure meta includes all these
   # fields at the beginning of build_in_hook(),
@@ -61,46 +80,46 @@ drake_meta <- function(target, config = drake::read_drake_config()) {
     meta$command <- get_standardized_command(target = target, config = config)
   }
   if (trigger %in% triggers_with_depends()){
-    meta$depends <- dependency_hash(target = target, config = config)
+    meta$dependency_hash <- dependency_hash(target = target, config = config)
   }
   if (trigger %in% triggers_with_file()){
-    meta$file <- file_hash(target = target, config = config)
-  }
-  meta
-}
-
-finish_meta <- function(target, meta, config){
-  if (is_file(target)) {
-    # Keep an updated modification time for each file.
-    meta$mtime <- file.mtime(drake::drake_unquote(target))
-    # If the target is a file output, then we know
-    # it needs to be rehashed.
-    if (!meta$imported){
-      meta$file <- rehash_file(target = target, config = config)
-    }
-  }
-  # If the user selected a non-default trigger,
-  # some of these fields might not be populated.
-  # Empty fields need to be filled so that the target
-  # can appear up to date in the next make().
-  if (is.null(meta$file)){
-    meta$file <- file_hash(target = target, config = config)
-  }
-  if (is.null(meta$command)){
-    meta$command <- get_standardized_command(target = target, config = config)
-  }
-  if (is.null(meta$depends)){
-    meta$depends <- dependency_hash(target = target, config = config)
+    meta$input_file_hash <- file_dependency_hash(
+      target = target, config = config, which = "input_files")
+    meta$output_file_hash <- file_dependency_hash(
+      target = target, config = config, which = "output_files")
   }
   meta
 }
 
 dependency_hash <- function(target, config) {
   dependencies(target, config) %>%
+    sort %>%
     self_hash(config = config) %>%
     digest::digest(algo = config$long_hash_algo)
 }
 
+file_dependency_hash <- function(
+  target,
+  config,
+  which = c("input_files", "output_files"),
+  size_cutoff = rehash_file_size_cutoff
+){
+  which <- match.arg(which)
+  files <- unlist(igraph::vertex_attr(
+    graph = config$graph,
+    name = which,
+    index = target
+  ))
+  vapply(
+    X = sort(files),
+    FUN = file_hash,
+    FUN.VALUE = character(1),
+    config = config,
+    size_cutoff = size_cutoff
+  ) %>%
+    digest::digest(algo = config$long_hash_algo)
+}
+
 self_hash <- Vectorize(function(target, config) {
   if (kernel_exists(target = target, config = config)) {
     config$cache$get_hash(target, namespace = "kernels")
@@ -119,6 +138,14 @@ rehash_file <- function(target, config) {
   )
 }
 
+safe_rehash_file <- function(target, config){
+  if (file.exists(drake_unquote(target))){
+    rehash_file(target = target, config = config)
+  } else {
+    as.character(NA)
+  }
+}
+
 should_rehash_file <- function(filename, new_mtime, old_mtime,
   size_cutoff){
   do_rehash <- file.size(filename) < size_cutoff | new_mtime > old_mtime
@@ -128,7 +155,8 @@ should_rehash_file <- function(filename, new_mtime, old_mtime,
   do_rehash
 }
 
-file_hash <- function(target, config, size_cutoff = 1e5) {
+file_hash <- function(
+  target, config, size_cutoff = rehash_file_size_cutoff) {
   if (is_file(target)) {
     filename <- drake::drake_unquote(target)
   } else {
