@@ -1,4 +1,5 @@
 sanitize_plan <- function(plan, allow_duplicated_targets = FALSE){
+  wildcards <- attr(plan, "wildcards")
   plan <- as_tibble(plan)
   for (field in drake_plan_non_factors()){
     if (!is.null(plan[[field]])){
@@ -13,7 +14,6 @@ sanitize_plan <- function(plan, allow_duplicated_targets = FALSE){
   if ("trigger" %in% colnames(plan)){
     plan$trigger <- parse_triggers(plan$trigger)
   }
-  plan <- file_outs_to_targets(plan)
   plan$target <- repair_target_names(plan$target)
   plan <- plan[nzchar(plan$target), ]
   plan$command[is.na(plan$command)] <- ""
@@ -22,7 +22,7 @@ sanitize_plan <- function(plan, allow_duplicated_targets = FALSE){
   if (!allow_duplicated_targets) {
     plan <- handle_duplicated_targets(plan[, cols])
   }
-  plan
+  structure(plan, wildcards = wildcards)
 }
 
 drake_plan_non_factors <- function(){
@@ -47,7 +47,6 @@ drake_plan_columns <- function(){
 }
 
 sanitize_targets <- function(plan, targets){
-  plan <- sanitize_plan(plan)
   targets <- repair_target_names(targets)
   sanitize_nodes(nodes = targets, choices = plan$target)
 }
@@ -57,7 +56,7 @@ sanitize_nodes <- function(nodes, choices){
     stop(
       "All import/target names are invalid ",
       "in argument 'targets', 'from', or 'subset' ",
-      "for make(), vis_drake_graph(), or similar.",
+      "for make() or similar function.",
       call. = FALSE
     )
   }
@@ -93,36 +92,6 @@ repair_target_names <- function(x){
   make.unique(x, sep = "_")
 }
 
-file_outs_to_targets <- function(plan){
-  index <- grepl("file_out", plan$command, fixed = TRUE)
-  plan$target[index] <- vapply(
-    plan$command[index],
-    single_file_out,
-    character(1)
-  )
-  plan$target[is_file(plan$target)] <-
-    plan$target[is_file(plan$target)] %>%
-    gsub(pattern = "^'|'$", replacement = "\"")
-  plan
-}
-
-single_file_out <- function(command){
-  file_out <- command_dependencies(command)$file_out
-  if (length(file_out) < 1){
-    stop("found an empty file_out() in command: ", command, call. = FALSE)
-  }
-  if (length(file_out) > 1){
-    warning(
-      "Multiple file outputs found for command `", command, "`. ",
-      "Choosing ", file_out[1], " as the target name.",
-      call. = FALSE
-    )
-    file_out[1]
-  } else {
-    file_out
-  }
-}
-
 parse_triggers <- function(x){
   x[is.na(x) | !nzchar(x)] <- "any"
   assert_legal_triggers(x)
