@@ -1,6 +1,7 @@
 drake_context("examples")
 
 test_with_dir("examples are listed and written", {
+  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   x <- drake_examples()
   expect_true(is.character(x) & length(x) > 0)
   for (i in x){
@@ -11,15 +12,22 @@ test_with_dir("examples are listed and written", {
     unlink(i, recursive = TRUE, force = TRUE)
   }
   expect_warning(drake_example(destination = getwd()))
-  expect_silent(drake_batchtools_tmpl_file("slurm"))
-  expect_error(drake_batchtools_tmpl_file("mtcars"))
 })
 
 test_with_dir("overwrites of report.Rmd handled correctly", {
+  skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   load_mtcars_example(overwrite = TRUE)
   load_mtcars_example(overwrite = FALSE)
   expect_warning(load_mtcars_example(overwrite = TRUE))
-  expect_warning(load_mtcars_example(to = "a", report_file = "b"))
-  expect_true(file.exists("b"))
   expect_false(file.exists("a"))
+  load_mtcars_example(report_file = "a")
+  expect_true(file.exists("a"))
+})
+
+test_with_dir("example template files", {
+  expect_true(is.character(drake_hpc_template_files()))
+  expect_true(length(drake_hpc_template_files()) > 0)
+  expect_false(file.exists("slurm_batchtools.tmpl"))
+  expect_silent(drake_hpc_template_file("slurm_batchtools.tmpl"))
+  expect_true(file.exists("slurm_batchtools.tmpl"))
 })
